@@ -1,12 +1,13 @@
 package org.herac.tuxguitar.android.action.impl.browser;
 
 import org.herac.tuxguitar.action.TGActionContext;
-import org.herac.tuxguitar.action.TGActionException;
 import org.herac.tuxguitar.android.action.TGActionBase;
-import org.herac.tuxguitar.android.browser.model.TGBrowserException;
+import org.herac.tuxguitar.android.browser.model.TGBrowserElement;
 import org.herac.tuxguitar.android.browser.model.TGBrowserSession;
 import org.herac.tuxguitar.util.TGContext;
 
+import java.util.List;
+
 public class TGBrowserRefreshAction extends TGActionBase{
 	
 	public static final String NAME = "action.browser.refresh";
@@ -17,14 +18,14 @@ public class TGBrowserRefreshAction extends TGActionBase{
 		super(context, NAME);
 	}
 	
-	protected void processAction(final TGActionContext context) {
-		try {
-			TGBrowserSession tgBrowserSession = (TGBrowserSession) context.getAttribute(ATTRIBUTE_SESSION);
-			if( tgBrowserSession.getBrowser() != null ) {
-				tgBrowserSession.setCurrentElements(tgBrowserSession.getBrowser().listElements());
-			}
-		} catch (TGBrowserException e)  {
-			throw new TGActionException(e);
+	protected void processAction(TGActionContext context) {
+		final TGBrowserSession tgBrowserSession = context.getAttribute(ATTRIBUTE_SESSION);
+		if( tgBrowserSession.getBrowser() != null ) {
+			tgBrowserSession.getBrowser().listElements(new TGBrowserActionCallBack<List<TGBrowserElement>>(this, context) {
+				public void onActionSuccess(TGActionContext context, List<TGBrowserElement> elements) {
+					tgBrowserSession.setCurrentElements(elements);
+				}
+			});
 		}
 	}
 }
