@@ -1,4 +1,5 @@
 #include "VST.h"
+#include "VSTEffect.h"
 
 VstIntPtr VSTCALLBACK VSTPluginCallback(AEffect *effect, VstInt32 opcode, VstInt32 index, VstIntPtr value, void *ptr, float opt)
 {
@@ -6,6 +7,10 @@ VstIntPtr VSTCALLBACK VSTPluginCallback(AEffect *effect, VstInt32 opcode, VstInt
 		case audioMasterVersion:
 			return 2400;
 		case audioMasterAutomate:
+			VSTEffectHandle *handle = NULL;
+			memcpy(&handle, &effect->resvd1, sizeof(handle));
+			VSTEffect_setUpdated(handle, true);
+			
 			return 1;
 		case audioMasterIdle:
 			effect->dispatcher(effect, effEditIdle, 0, 0, 0, 0);
