@@ -30,12 +30,11 @@ import org.herac.tuxguitar.app.action.impl.effects.TGOpenTremoloPickingDialogAct
 import org.herac.tuxguitar.app.action.impl.effects.TGOpenTrillDialogAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseAllDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseCurrentDocumentAction;
+import org.herac.tuxguitar.app.action.impl.file.TGCloseDocumentAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGCloseOtherDocumentsAction;
 import org.herac.tuxguitar.app.action.impl.file.TGExitAction;
-import org.herac.tuxguitar.app.action.impl.file.TGExportFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGExportSongAction;
-import org.herac.tuxguitar.app.action.impl.file.TGImportFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGImportSongAction;
 import org.herac.tuxguitar.app.action.impl.file.TGOpenFileAction;
 import org.herac.tuxguitar.app.action.impl.file.TGOpenURLAction;
@@ -54,6 +53,10 @@ import org.herac.tuxguitar.app.action.impl.insert.TGOpenTextDialogAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetChordDiagramEnabledAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetChordNameEnabledAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetCompactViewAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleDecrementAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleIncrementAction;
+import org.herac.tuxguitar.app.action.impl.layout.TGSetLayoutScaleResetAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetLinearLayoutAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetMultitrackViewAction;
 import org.herac.tuxguitar.app.action.impl.layout.TGSetPageLayoutAction;
@@ -69,7 +72,6 @@ import org.herac.tuxguitar.app.action.impl.marker.TGOpenMarkerEditorAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGRemoveMarkerAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGToggleMarkerListAction;
 import org.herac.tuxguitar.app.action.impl.marker.TGUpdateMarkerAction;
-import org.herac.tuxguitar.app.action.impl.measure.TGCopyMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoFirstMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoLastMeasureAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGGoNextMeasureAction;
@@ -79,7 +81,6 @@ import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureCleanDialogActio
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureCopyDialogAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasurePasteDialogAction;
 import org.herac.tuxguitar.app.action.impl.measure.TGOpenMeasureRemoveDialogAction;
-import org.herac.tuxguitar.app.action.impl.measure.TGPasteMeasureAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenBeatMoveDialogAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenStrokeDownDialogAction;
 import org.herac.tuxguitar.app.action.impl.note.TGOpenStrokeUpDialogAction;
@@ -105,6 +106,7 @@ import org.herac.tuxguitar.app.action.impl.track.TGGoNextTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGGoPreviousTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGGoToTrackAction;
 import org.herac.tuxguitar.app.action.impl.track.TGOpenTrackPropertiesDialogAction;
+import org.herac.tuxguitar.app.action.impl.track.TGOpenTrackTuningDialogAction;
 import org.herac.tuxguitar.app.action.impl.track.TGToggleLyricEditorAction;
 import org.herac.tuxguitar.app.action.impl.transport.TGOpenTransportModeDialogAction;
 import org.herac.tuxguitar.app.action.impl.transport.TGTransportCountDownAction;
@@ -118,10 +120,11 @@ import org.herac.tuxguitar.app.action.impl.view.TGHideExternalBeatAction;
 import org.herac.tuxguitar.app.action.impl.view.TGOpenViewAction;
 import org.herac.tuxguitar.app.action.impl.view.TGShowExternalBeatAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleChannelsDialogAction;
+import org.herac.tuxguitar.app.action.impl.view.TGToggleEditToolbarAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleFretBoardEditorAction;
+import org.herac.tuxguitar.app.action.impl.view.TGToggleMainToolbarAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleMatrixEditorAction;
 import org.herac.tuxguitar.app.action.impl.view.TGTogglePianoEditorAction;
-import org.herac.tuxguitar.app.action.impl.view.TGToggleToolbarsAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleTransportDialogAction;
 import org.herac.tuxguitar.app.action.impl.view.TGToggleViewAction;
 import org.herac.tuxguitar.editor.action.TGActionBase;
@@ -140,6 +143,7 @@ import org.herac.tuxguitar.editor.action.composition.TGChangeTripletFeelAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatAlternativeAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatCloseAction;
 import org.herac.tuxguitar.editor.action.composition.TGRepeatOpenAction;
+import org.herac.tuxguitar.editor.action.duration.TGChangeDivisionTypeDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGChangeDottedDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGChangeDoubleDottedDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGDecrementDurationAction;
@@ -184,8 +188,10 @@ import org.herac.tuxguitar.editor.action.measure.TGAddMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGAddMeasureListAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureListAction;
+import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureFromAction;
 import org.herac.tuxguitar.editor.action.measure.TGInsertMeasuresAction;
+import org.herac.tuxguitar.editor.action.measure.TGPasteMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureRangeAction;
 import org.herac.tuxguitar.editor.action.note.TGChangeNoteAction;
@@ -231,6 +237,7 @@ import org.herac.tuxguitar.editor.action.track.TGSetTrackLyricsAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackMuteAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackNameAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackSoloAction;
+import org.herac.tuxguitar.editor.action.track.TGSetTrackStringCountAction;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGActionInstaller {
@@ -260,10 +267,9 @@ public class TGActionInstaller {
 		installAction(new TGReadURLAction(context));
 		installAction(new TGOpenFileAction(context));
 		installAction(new TGImportSongAction(context));
-		installAction(new TGImportFileAction(context));
 		installAction(new TGExportSongAction(context));
-		installAction(new TGExportFileAction(context));
 		installAction(new TGCloseDocumentsAction(context));
+		installAction(new TGCloseDocumentAction(context));
 		installAction(new TGCloseCurrentDocumentAction(context));
 		installAction(new TGCloseOtherDocumentsAction(context));
 		installAction(new TGCloseAllDocumentsAction(context));
@@ -316,6 +322,7 @@ public class TGActionInstaller {
 		installAction(new TGSetTrackInfoAction(context));
 		installAction(new TGSetTrackNameAction(context));
 		installAction(new TGSetTrackChannelAction(context));
+		installAction(new TGSetTrackStringCountAction(context));
 		installAction(new TGChangeTrackTuningAction(context));
 		installAction(new TGCopyTrackFromAction(context));
 		installAction(new TGSetTrackLyricsAction(context));
@@ -397,6 +404,7 @@ public class TGActionInstaller {
 		installAction(new TGSetThirtySecondDurationAction(context));
 		installAction(new TGSetSixtyFourthDurationAction(context));
 		installAction(new TGSetDivisionTypeDurationAction(context));
+		installAction(new TGChangeDivisionTypeDurationAction(context));
 		installAction(new TGChangeDottedDurationAction(context));
 		installAction(new TGChangeDoubleDottedDurationAction(context));
 		installAction(new TGIncrementDurationAction(context));
@@ -449,6 +457,10 @@ public class TGActionInstaller {
 		installAction(new TGSetCompactViewAction(context));
 		installAction(new TGSetChordNameEnabledAction(context));
 		installAction(new TGSetChordDiagramEnabledAction(context));
+		installAction(new TGSetLayoutScaleAction(context));
+		installAction(new TGSetLayoutScaleIncrementAction(context));
+		installAction(new TGSetLayoutScaleDecrementAction(context));
+		installAction(new TGSetLayoutScaleResetAction(context));
 		
 		//tools
 		installAction(new TGSelectScaleAction(context));
@@ -496,6 +508,7 @@ public class TGActionInstaller {
 		installAction(new TGOpenMeasureRemoveDialogAction(context));
 		installAction(new TGOpenMeasureCopyDialogAction(context));
 		installAction(new TGOpenMeasurePasteDialogAction(context));
+		installAction(new TGOpenTrackTuningDialogAction(context));
 		installAction(new TGOpenTrackPropertiesDialogAction(context));
 		installAction(new TGOpenScaleDialogAction(context));
 		installAction(new TGOpenURLAction(context));
@@ -511,7 +524,8 @@ public class TGActionInstaller {
 		installAction(new TGToggleBrowserAction(context));
 		installAction(new TGToggleTransportDialogAction(context));
 		installAction(new TGToggleMarkerListAction(context));
-		installAction(new TGToggleToolbarsAction(context));
+		installAction(new TGToggleMainToolbarAction(context));
+		installAction(new TGToggleEditToolbarAction(context));
 		
 		installAction(new TGOpenDocumentationDialogAction(context));
 		installAction(new TGOpenAboutDialogAction(context));
